@@ -8,6 +8,8 @@ import six
 
 from .util import ApiXmlHelper
 from .exceptions import KempTechApiException, CommandNotAvailableException
+from .exceptions import ConnectionTimeoutException
+
 
 
 requests.packages.urllib3.disable_warnings()
@@ -57,6 +59,9 @@ class HttpClient(object):
                 raise KempTechApiException(code=response.status_code)
             else:
                 response.raise_for_status()
+        except exceptions.ConnectTimeout:
+            log.exception("The connection timed out to %s.", self.endpoint)
+            raise ConnectionTimeoutException(self.endpoint)
         except exceptions.ConnectionError:
             log.exception("A connection error occurred to %s.", self.endpoint)
             raise
